<?php
/**
 * Avalanche Material functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Avalanche_Material
 */

if ( ! function_exists( 'avalanche_material_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function avalanche_material_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Avalanche Material, use a find and replace
	 * to change 'avalanche-material' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'avalanche-material', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.

    function register_my_menus() {
      register_nav_menus(
        array(
          'primary' => esc_html__( 'Primary', 'avalanche-material' )
        )
      );
    }
add_action( 'init', 'register_my_menus' );
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'avalanche_material_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'avalanche_material_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function avalanche_material_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'avalanche_material_content_width', 640 );
}
add_action( 'after_setup_theme', 'avalanche_material_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function avalanche_material_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'avalanche-material' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'avalanche_material_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function avalanche_material_scripts() {
	wp_enqueue_style( 'avalanche-material-style', get_stylesheet_uri() );

	wp_enqueue_script( 'avalanche-material-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
    
    wp_enqueue_script( 'avalanche-material-extra', get_template_directory_uri() . '/js/extra.js', array(), '20160303', true );
    
    wp_enqueue_script( 'avalanche-material-material', get_template_directory_uri() . '/js/material.min.js', array(), '20160212', true );

    wp_enqueue_script( 'avalanche-material-ripples', get_template_directory_uri() . '/js/ripples.min.js', array(), '20160212', true );
    
    wp_enqueue_script( 'avalanche-material-bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array(), '20160212', true );
    
	wp_enqueue_script( 'avalanche-material-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
    
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'avalanche_material_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Custom Avalanche Material
 */
/* Add Colors to Customizer ------------------------------------------------------------*/
function Ari_customize_register( $wp_customize ) {
      $colors = array();
    $colors[] = array(
      'slug'=>'primary_color', 
      'default' => '#2196F3;',
      'label' => __('Primary Color', 'avalanche-material')
    );
    $colors[] = array(
      'slug'=>'navbar_color', 
      'default' => '#ffffff;',
      'label' => __('Nav Bar Color', 'avalanche-material')
    );
    $colors[] = array(
      'slug'=>'navbar_link_color', 
      'default' => '#727272;',
      'label' => __('Nav Bar Link Color', 'avalanche-material')
    );
    $colors[] = array(
      'slug'=>'accent_color', 
      'default' => ' #8BC34A;',
      'label' => __('Accent Color', 'avalanche-material')
    );
    foreach( $colors as $color ) {
      // SETTINGS
      $wp_customize->add_setting(
        $color['slug'], array(
          'default' => $color['default'],
          'type' => 'option', 
          'capability' => 'edit_theme_options',
          'sanitize_callback' => 'color_sanatize'
        )
      );
      // CONTROLS
      $wp_customize->add_control(
        new WP_Customize_Color_Control(
          $wp_customize,
          $color['slug'], 
          array('label' => $color['label'], 
          'section' => 'colors',
          'settings' => $color['slug'])
        )
      );
    }
}
add_action( 'customize_register', 'Ari_customize_register' );

function color_sanatize ( $value ) {
 
    return $value;
}
/* Add Site Logo to Customizer ------------------------------------------------------------*/
function themeslug_theme_customizer( $wp_customize ) {
    $wp_customize->add_section( 'themeslug_logo_section' , array(
        'title'       => __( 'Logo', 'avalanche-material' ),
        'priority'    => 30,
        'description' => 'Upload a logo to replace the default site name and description in the header',
    ) );
    $wp_customize->add_setting( 'themeslug_logo' , array(
        'sanitize_callback' => 'logo_sanatize'
    ) );
    
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'themeslug_logo', array(
        'label'    => __( 'Logo', 'avalanche-material' ),
        'section'  => 'themeslug_logo_section',
        'settings' => 'themeslug_logo',
    ) ) );
}
add_action( 'customize_register', 'themeslug_theme_customizer' );

function logo_sanatize ( $value ) {
 
    return $value;
}

/* REGISTER FOOTER WIDGETS ------------------------------------------------------------*/

if (function_exists('register_sidebar')) {
    register_sidebar(array(
        'name' => 'Footer Left',
        'id'   => 'footer-left-widget',
        'description'   => 'Left Footer widget position.',
        'before_widget' => '<div id="%1$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2>',
        'after_title'   => '</h2>'
    ));

    register_sidebar(array(
        'name' => 'Footer Center',
        'id'   => 'footer-center-widget',
        'description'   => 'Centre Footer widget position.',
        'before_widget' => '<div id="%1$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2>',
        'after_title'   => '</h2>'
    ));

    register_sidebar(array(
        'name' => 'Footer Right',
        'id'   => 'footer-right-widget',
        'description'   => 'Right Footer widget position.',
        'before_widget' => '<div id="%1$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h2>',
        'after_title'   => '</h2>'
    ));
}
//Adds read more to entry-summary
function new_excerpt_more($more) {
       global $post;
	return '<div class="moretext">@more@</div>';
}
add_filter('excerpt_more', 'new_excerpt_more');


// Adds a widget area.
if (function_exists('register_sidebar')) {
	register_sidebar(array(
	'name' => 'Extra Header Widget Area',
	'id' => 'extra-widget-area',
	'description' => 'Extra widget area after the header',
	'before_widget' => '<div class="widget my-extra-widget">',
	'after_widget' => '</div>',
	'before_title' => '<h2>',
	'after_title' => '</h2>'
	));
}
/**
 * Registers an editor stylesheet for the theme.
 */
add_editor_style( 'css/custom-editor-style.css' );
